.. tricircle documentation master file, created by
   sphinx-quickstart on Wed Dec 2 17:00:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====================================
Welcome to Tricircle's documentation!
=====================================

Tricircle User Guide
====================
.. toctree::
   :maxdepth: 3

   user/index

Tricircle Contribution Guide
============================
.. toctree::
   :maxdepth: 2

   contributor/index

Tricircle Admin Guide
=====================
.. toctree::
   :maxdepth: 3

   admin/index

Tricircle Installation Guide
============================
.. toctree::
   :maxdepth: 3

   install/index

Tricircle Configuration Guide
=============================
.. toctree::
   :maxdepth: 3

   configuration/index

Tricircle Networking Guide
==========================
.. toctree::
   :maxdepth: 4

   networking/index

